# PXE File System

A simple file system MCP server.

## Installation

uvx:

```
{
  "mcpServers": {
    "pickaxe-mcp-file-system": {
      "command": "uvx",
      "args": [
        "pickaxe-mcp-file-system",
        "/data"
      ]
    }
  }
}
```
